@@ -8,14 +8,6 @@ arkhe::remove_NA
 #' @export
 arkhe::remove_zero
 
-#' @importFrom arkhe remove_constant
-#' @export
-arkhe::remove_constant
-
-#' @importFrom arkhe sparsity
-#' @export
-arkhe::sparsity
-
 # REEXPORT FROM KHROMA
 
 #' @importFrom khroma color
