@@ -45,7 +45,8 @@ setMethod(
   definition = function(object) {
     z <- methods::callNextMethod()
     .GroupedILR(z, group_indices = group_indices(object),
-                group_levels = group_levels(object))
+                group_levels = group_levels(object),
+                group_ordered = is_ordered(object))
   }
 )
 
@@ -72,7 +73,8 @@ setMethod(
   definition = function(object) {
     z <- methods::callNextMethod()
     .GroupedILR(z, group_indices = group_indices(object),
-                group_levels = group_levels(object))
+                group_levels = group_levels(object),
+                group_ordered = is_ordered(object))
   }
 )
 
@@ -97,7 +99,8 @@ setMethod(
   definition = function(object) {
     z <- methods::callNextMethod()
     .GroupedILR(z, group_indices = group_indices(object),
-                group_levels = group_levels(object))
+                group_levels = group_levels(object),
+                group_ordered = is_ordered(object))
   }
 )
 
